bayespy.inference.vmp.transformations.RotateMultiple.nodes
==========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.nodes